@@ -159,6 +159,7 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         initLuaState(ls, langDefPath, pluginReadFilePath, outputType);
 
         lua_register (ls.getState(),"AddKeyword",luaAddKeyword);
+        lua_register (ls.getState(),"RemoveKeyword",luaRemoveKeyword);
 
         SyntaxReader **s = (SyntaxReader **)lua_newuserdata(ls.getState(), sizeof(SyntaxReader *));
         *s=this;
@@ -186,7 +187,7 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         int idx=1;
         int kwId=0;
         while (ls["Keywords"][idx].value() !=Diluculum::Nil) {
-            kwId= generateNewKWClass ( ls["Keywords"][idx]["Id"].value().asNumber() );
+            kwId= generateNewKWClass ( ls["Keywords"][idx]["Id"].value().asInteger() );
 
             if (ls["Keywords"][idx]["List"].value()!=Diluculum::Nil) {
                 int listIdx=1;
@@ -199,7 +200,7 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
                 string reString=StringTools::trim(ls["Keywords"][idx]["Regex"].value().asString());
                 int captGroup=-1;
                 if (ls["Keywords"][idx]["Group"].value()!=Diluculum::Nil) {
-                    captGroup=ls["Keywords"][idx]["Group"].value().asNumber();
+                    captGroup=ls["Keywords"][idx]["Group"].value().asInteger();
                 }
                 regex.push_back ( new RegexElement ( KEYWORD, KEYWORD_END, reString, kwId, captGroup ) );
             }
@@ -391,6 +392,10 @@ void SyntaxReader::addKeyword(unsigned int groupID, const string& kw)
         keywords.insert ( make_pair (kw, groupID ) );
     }
 }
+void SyntaxReader::removeKeyword(const string& kw)
+{
+    keywords.erase(kw);
+}
 
 int SyntaxReader::isKeyword ( const string &s )
 {
@@ -414,6 +419,22 @@ int SyntaxReader::luaAddKeyword (lua_State *L)
     return 1;
 }
 
+int SyntaxReader::luaRemoveKeyword (lua_State *L)
+{
+    int retVal=0;
+    if (lua_gettop(L)==1) {
+        const char*keyword=lua_tostring(L, 1);
+        lua_getglobal(L, GLOBAL_SR_INSTANCE_NAME);
+        SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 2));
+        if (*a) {
+            (*a)->removeKeyword(keyword);
+            retVal=1;
+        }
+    }
+    lua_pushboolean(L, retVal);
+    return 1;
+}
+
 void SyntaxReader::restoreLangEndDelim(const string& langPath)
 {
     if ( !langPath.empty()&& nestedStateEndDelimiters.count(langPath) ) {
